#ifndef NT2_INCLUDE_CONSTANTS_PIO_4_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_PIO_4_HPP_INCLUDED

#include <nt2/trigonometric/include/constants/pio_4.hpp>

#endif
